pub fn anchor(
value: &CollaborationAnchor,
scope: &CollaborationScope,
) -> Result<CollaborationAnchor, Error>Expand description
Bind an API anchor to the canonical scope before signing or admitting it.
pub fn anchor(
value: &CollaborationAnchor,
scope: &CollaborationScope,
) -> Result<CollaborationAnchor, Error>Bind an API anchor to the canonical scope before signing or admitting it.