pub fn operation_id(record: &SignedRecord) -> Result<ContentHash, Error>Expand description
The public causal vocabulary is the outer replication operation identity.
pub fn operation_id(record: &SignedRecord) -> Result<ContentHash, Error>The public causal vocabulary is the outer replication operation identity.