#[repr(i32)]pub enum AccountDeletionOutcome {
Unspecified = 0,
Completed = 1,
Scheduled = 2,
AlreadyDeleted = 3,
}Variants
Unspecified = 0
Completed = 1
Account-owned live data was removed before this response was produced.
Scheduled = 2
Some retained data remains until retained_data_delete_after.
AlreadyDeleted = 3
The same account deletion had already completed; no work was repeated.
Implementations
Sourceimpl AccountDeletionOutcome
impl AccountDeletionOutcome
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of AccountDeletionOutcome.
Sourcepub fn from_i32(value: i32) -> Option<AccountDeletionOutcome>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<AccountDeletionOutcome>
Use the TryFrom<i32> implementation instead
Converts an i32 to a AccountDeletionOutcome, or None if value is not a valid variant.
Sourceimpl AccountDeletionOutcome
impl AccountDeletionOutcome
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<AccountDeletionOutcome>
pub fn from_str_name(value: &str) -> Option<AccountDeletionOutcome>
Creates an enum from field names used in the ProtoBuf definition.