#[repr(i32)]pub enum ForeignDependencyOrigin {
Unspecified = 0,
Import = 1,
Native = 2,
}Expand description
References to originals already durably installed through their own carrier. Origin is immutable per Thread; foreign entries never grant permission.
Variants
Implementations
Sourceimpl ForeignDependencyOrigin
impl ForeignDependencyOrigin
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of ForeignDependencyOrigin.
Sourcepub fn from_i32(value: i32) -> Option<ForeignDependencyOrigin>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ForeignDependencyOrigin>
Use the TryFrom<i32> implementation instead
Converts an i32 to a ForeignDependencyOrigin, or None if value is not a valid variant.
Sourceimpl ForeignDependencyOrigin
impl ForeignDependencyOrigin
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<ForeignDependencyOrigin>
pub fn from_str_name(value: &str) -> Option<ForeignDependencyOrigin>
Creates an enum from field names used in the ProtoBuf definition.