#[repr(i32)]pub enum ImportAuthorityRecordKind {
Unspecified = 0,
ThreadOperationV1 = 1,
OwnershipClaimV1 = 2,
OwnershipResolutionV1 = 3,
}Variants
Implementations
Sourceimpl ImportAuthorityRecordKind
impl ImportAuthorityRecordKind
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of ImportAuthorityRecordKind.
Sourcepub fn from_i32(value: i32) -> Option<ImportAuthorityRecordKind>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ImportAuthorityRecordKind>
Use the TryFrom<i32> implementation instead
Converts an i32 to a ImportAuthorityRecordKind, or None if value is not a valid variant.
Sourceimpl ImportAuthorityRecordKind
impl ImportAuthorityRecordKind
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<ImportAuthorityRecordKind>
pub fn from_str_name(value: &str) -> Option<ImportAuthorityRecordKind>
Creates an enum from field names used in the ProtoBuf definition.