#[repr(i32)]pub enum ImportDelegationPurpose {
Unspecified = 0,
ImportConversionV1 = 1,
}Expand description
Fixed field order, counted bytes, BE integers and domain-separated digests follow owner_records.proto, not protobuf serialization. See the normative contract and the ONE fixed Rust/TS fixture in tests/fixtures/.
Variants
Implementations
Sourceimpl ImportDelegationPurpose
impl ImportDelegationPurpose
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of ImportDelegationPurpose.
Sourcepub fn from_i32(value: i32) -> Option<ImportDelegationPurpose>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ImportDelegationPurpose>
Use the TryFrom<i32> implementation instead
Converts an i32 to a ImportDelegationPurpose, or None if value is not a valid variant.
Sourceimpl ImportDelegationPurpose
impl ImportDelegationPurpose
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<ImportDelegationPurpose>
pub fn from_str_name(value: &str) -> Option<ImportDelegationPurpose>
Creates an enum from field names used in the ProtoBuf definition.