#[repr(i32)]pub enum NativeGenesisOwnerKind {
Unspecified = 0,
Account = 1,
LocalKey = 2,
}Expand description
Separate native contract; never selected because an import lacks delegation. Canonical layouts and producer order: docs/alpha-v2/native-host-witness.md.
Variants
Implementations
Sourceimpl NativeGenesisOwnerKind
impl NativeGenesisOwnerKind
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of NativeGenesisOwnerKind.
Sourcepub fn from_i32(value: i32) -> Option<NativeGenesisOwnerKind>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<NativeGenesisOwnerKind>
Use the TryFrom<i32> implementation instead
Converts an i32 to a NativeGenesisOwnerKind, or None if value is not a valid variant.
Sourceimpl NativeGenesisOwnerKind
impl NativeGenesisOwnerKind
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<NativeGenesisOwnerKind>
pub fn from_str_name(value: &str) -> Option<NativeGenesisOwnerKind>
Creates an enum from field names used in the ProtoBuf definition.