#[repr(i32)]pub enum SessionStateFilter {
Unspecified = 0,
Active = 1,
Ended = 2,
All = 3,
}Expand description
State filtering never expands the caller’s authorized session scope.
Variants
Unspecified = 0
Compatibility default: ALL, including ended sessions, as before this field.
Active = 1
Recommended for settings. Not revoked and expires_at is later than the server’s snapshot time. Apply before paging, budgets and matching_count.
Ended = 2
Revoked (including signed out) or expired at the server’s snapshot time.
All = 3
Implementations
Sourceimpl SessionStateFilter
impl SessionStateFilter
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of SessionStateFilter.
Sourcepub fn from_i32(value: i32) -> Option<SessionStateFilter>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<SessionStateFilter>
Use the TryFrom<i32> implementation instead
Converts an i32 to a SessionStateFilter, or None if value is not a valid variant.
Sourceimpl SessionStateFilter
impl SessionStateFilter
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<SessionStateFilter>
pub fn from_str_name(value: &str) -> Option<SessionStateFilter>
Creates an enum from field names used in the ProtoBuf definition.