pub struct AgentStart {
pub session_id: String,
pub subject: String,
pub namespace: String,
pub model: Option<String>,
pub provider: Option<String>,
pub cursor_path: Option<String>,
pub started_at_ms: u64,
pub thread: Option<String>,
}Expand description
Agent session started.
Fields
session_id: Stringsubject: Stringnamespace: Stringmodel: Option<String>provider: Option<String>cursor_path: Option<String>started_at_ms: u64Unix epoch milliseconds when the session started.
thread: Option<String>Thread ref when the publisher is on a thread (weft#1277 / tapestry#398). Optional — not every session is on a thread (human browsing, agent between threads). Empty string must not be used as a sentinel; omit when unattributed.
Implementations
Sourceimpl AgentStart
impl AgentStart
Sourcepub fn model(&self) -> &str
pub fn model(&self) -> &str
Returns the value of model, or the default value if model is unset.
Sourcepub fn provider(&self) -> &str
pub fn provider(&self) -> &str
Returns the value of provider, or the default value if provider is unset.
Sourcepub fn cursor_path(&self) -> &str
pub fn cursor_path(&self) -> &str
Returns the value of cursor_path, or the default value if cursor_path is unset.