pub enum Selection {
WholeSource(bool),
Symbols(ReviewSymbols),
}Expand description
Exactly one arm. A symbol selection is bounded and tied to source.
Variants
WholeSource(bool)
Symbols(ReviewSymbols)
Implementations
Sourceimpl Selection
impl Selection
Sourcepub fn merge(
field: &mut Option<Selection>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Selection>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.