pub enum Revision {
State(StateId),
GitCommitOid(String),
}Variants
State(StateId)
GitCommitOid(String)
Exact lower-case object ID, never a mutable ref or abbreviated hash.
Implementations
Sourceimpl Revision
impl Revision
Sourcepub fn merge(
field: &mut Option<Revision>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Revision>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.