pub struct AnnotationPropertyPredicate {
pub key: String,
pub comparison: i32,
pub value: Option<AnnotationValue>,
}Fields
key: Stringcomparison: i32value: Option<AnnotationValue>Absent only for EXISTS. No string/numeric or integer/decimal coercion. Ordering is supported only for integer and decimal values.
Implementations
Sourceimpl AnnotationPropertyPredicate
impl AnnotationPropertyPredicate
Sourcepub fn comparison(&self) -> Comparison
pub fn comparison(&self) -> Comparison
Returns the enum value of comparison, or the default if the field is set to an invalid enum value.
Sourcepub fn set_comparison(&mut self, value: Comparison)
pub fn set_comparison(&mut self, value: Comparison)
Sets comparison to the provided enum value.