pub struct AttentionItem {Show 13 fields
pub ref: Option<RecordRef>,
pub version: Vec<u8>,
pub subject: Option<EntityRef>,
pub headline: String,
pub detail: String,
pub priority: u32,
pub resolution: i32,
pub pinned: bool,
pub capture: Option<CaptureSummary>,
pub actions: Vec<ActionAvailability>,
pub requirements: Vec<Requirement>,
pub analysis_coverage: i32,
pub created_at: Option<Timestamp>,
}Fields
ref: Option<RecordRef>version: Vec<u8>subject: Option<EntityRef>headline: Stringdetail: Stringpriority: u32resolution: i32pinned: boolcapture: Option<CaptureSummary>actions: Vec<ActionAvailability>requirements: Vec<Requirement>analysis_coverage: i32created_at: Option<Timestamp>Implementations
Sourceimpl AttentionItem
impl AttentionItem
Sourcepub fn resolution(&self) -> Resolution
pub fn resolution(&self) -> Resolution
Returns the enum value of resolution, or the default if the field is set to an invalid enum value.
Sourcepub fn set_resolution(&mut self, value: Resolution)
pub fn set_resolution(&mut self, value: Resolution)
Sets resolution to the provided enum value.
Sourcepub fn analysis_coverage(&self) -> Coverage
pub fn analysis_coverage(&self) -> Coverage
Returns the enum value of analysis_coverage, or the default if the field is set to an invalid enum value.
Sourcepub fn set_analysis_coverage(&mut self, value: Coverage)
pub fn set_analysis_coverage(&mut self, value: Coverage)
Sets analysis_coverage to the provided enum value.