pub struct BehaviorAnalysisCoverage {
pub analysis: Option<RecordRef>,
pub base: Option<RevisionRef>,
pub source: Option<RevisionRef>,
pub analyzed: Vec<BehaviorScope>,
pub omitted: Vec<BehaviorScope>,
pub selection_exhausted: bool,
pub versions: Option<BehaviorVersions>,
}Fields
analysis: Option<RecordRef>base: Option<RevisionRef>source: Option<RevisionRef>analyzed: Vec<BehaviorScope>omitted: Vec<BehaviorScope>selection_exhausted: boolFalse for a bounded prefix. Page/checkpoint describe delivery completeness; this field describes analysis of the requested pattern and scope.
versions: Option<BehaviorVersions>Trait Implementations
Sourceimpl Clone for BehaviorAnalysisCoverage
impl Clone for BehaviorAnalysisCoverage
Sourcefn clone(&self) -> BehaviorAnalysisCoverage
fn clone(&self) -> BehaviorAnalysisCoverage
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BehaviorAnalysisCoverage
impl Debug for BehaviorAnalysisCoverage
Sourceimpl Default for BehaviorAnalysisCoverage
impl Default for BehaviorAnalysisCoverage
Sourcefn default() -> BehaviorAnalysisCoverage
fn default() -> BehaviorAnalysisCoverage
Returns the “default value” for a type. Read more
Sourceimpl Message for BehaviorAnalysisCoverage
impl Message for BehaviorAnalysisCoverage
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for BehaviorAnalysisCoverage
impl PartialEq for BehaviorAnalysisCoverage
impl StructuralPartialEq for BehaviorAnalysisCoverage