pub struct BehaviorBinding {
pub id: String,
pub occurrence_id: String,
pub name: String,
pub value_id: Option<String>,
pub declaration: Option<BehaviorSource>,
pub lexical_scope: Option<BehaviorByteSpan>,
pub support: i32,
pub limitations: Vec<i32>,
pub provenance: i32,
}Fields
id: Stringoccurrence_id: StringThe written occurrence remains an expression, even when resolved.
name: Stringvalue_id: Option<String>declaration: Option<BehaviorSource>lexical_scope: Option<BehaviorByteSpan>Half-open byte span in the declaration’s exact revision/path/blob. The containing block’s text is not repeated for every binding occurrence.
support: i32limitations: Vec<i32>provenance: i32Implementations
Sourceimpl BehaviorBinding
impl BehaviorBinding
Sourcepub fn value_id(&self) -> &str
pub fn value_id(&self) -> &str
Returns the value of value_id, or the default value if value_id is unset.
Sourcepub fn support(&self) -> BehaviorSupport
pub fn support(&self) -> BehaviorSupport
Returns the enum value of support, or the default if the field is set to an invalid enum value.
Sourcepub fn set_support(&mut self, value: BehaviorSupport)
pub fn set_support(&mut self, value: BehaviorSupport)
Sets support to the provided enum value.
Sourcepub fn limitations(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<BehaviorLimitation>> ⓘ
pub fn limitations( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<BehaviorLimitation>> ⓘ
Returns an iterator which yields the valid enum values contained in limitations.
Sourcepub fn push_limitations(&mut self, value: BehaviorLimitation)
pub fn push_limitations(&mut self, value: BehaviorLimitation)
Appends the provided enum value to limitations.
Sourcepub fn provenance(&self) -> BehaviorProvenance
pub fn provenance(&self) -> BehaviorProvenance
Returns the enum value of provenance, or the default if the field is set to an invalid enum value.
Sourcepub fn set_provenance(&mut self, value: BehaviorProvenance)
pub fn set_provenance(&mut self, value: BehaviorProvenance)
Sets provenance to the provided enum value.