pub struct BehaviorVersions {
pub analyzer: String,
pub analyzer_version: String,
pub grammar_version: String,
pub symbol_extractor_version: u32,
pub expression_extractor_version: u32,
pub binding_resolver_version: u32,
pub comparison_version: u32,
}Fields
analyzer: Stringanalyzer_version: Stringgrammar_version: Stringsymbol_extractor_version: u32expression_extractor_version: u32binding_resolver_version: u32comparison_version: u32Trait Implementations
Sourceimpl Clone for BehaviorVersions
impl Clone for BehaviorVersions
Sourcefn clone(&self) -> BehaviorVersions
fn clone(&self) -> BehaviorVersions
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BehaviorVersions
impl Debug for BehaviorVersions
Sourceimpl Default for BehaviorVersions
impl Default for BehaviorVersions
Sourcefn default() -> BehaviorVersions
fn default() -> BehaviorVersions
Returns the “default value” for a type. Read more
impl Eq for BehaviorVersions
Sourceimpl Hash for BehaviorVersions
impl Hash for BehaviorVersions
Sourceimpl Message for BehaviorVersions
impl Message for BehaviorVersions
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for BehaviorVersions
impl PartialEq for BehaviorVersions
impl StructuralPartialEq for BehaviorVersions