pub struct BrowserPairingApprovalBinding {
pub format_version: u32,
pub root_public_key: Vec<u8>,
pub subject_public_key: Vec<u8>,
pub account_id: String,
pub credential_digest: Vec<u8>,
pub pairing_challenge: Vec<u8>,
pub not_before_unix_seconds: i64,
pub expires_at_unix_seconds: i64,
}Fields
format_version: u32root_public_key: Vec<u8>subject_public_key: Vec<u8>account_id: Stringcredential_digest: Vec<u8>pairing_challenge: Vec<u8>not_before_unix_seconds: i64expires_at_unix_seconds: i64Trait Implementations
Sourceimpl Clone for BrowserPairingApprovalBinding
impl Clone for BrowserPairingApprovalBinding
Sourcefn clone(&self) -> BrowserPairingApprovalBinding
fn clone(&self) -> BrowserPairingApprovalBinding
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for BrowserPairingApprovalBinding
impl Default for BrowserPairingApprovalBinding
Sourcefn default() -> BrowserPairingApprovalBinding
fn default() -> BrowserPairingApprovalBinding
Returns the “default value” for a type. Read more
impl Eq for BrowserPairingApprovalBinding
Sourceimpl Hash for BrowserPairingApprovalBinding
impl Hash for BrowserPairingApprovalBinding
Sourceimpl Message for BrowserPairingApprovalBinding
impl Message for BrowserPairingApprovalBinding
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl StructuralPartialEq for BrowserPairingApprovalBinding