pub struct CancelImportJobRequest {
pub client_operation_id: String,
pub destination: Option<SpoolRef>,
pub logical_job_id: Vec<u8>,
pub cancellation_id: Vec<u8>,
pub expected_authority_epoch: u64,
}Fields
client_operation_id: Stringdestination: Option<SpoolRef>logical_job_id: Vec<u8>cancellation_id: Vec<u8>Trait Implementations
Sourceimpl Clone for CancelImportJobRequest
impl Clone for CancelImportJobRequest
Sourcefn clone(&self) -> CancelImportJobRequest
fn clone(&self) -> CancelImportJobRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CancelImportJobRequest
impl Debug for CancelImportJobRequest
Sourceimpl Default for CancelImportJobRequest
impl Default for CancelImportJobRequest
Sourcefn default() -> CancelImportJobRequest
fn default() -> CancelImportJobRequest
Returns the “default value” for a type. Read more
impl Eq for CancelImportJobRequest
Sourceimpl Hash for CancelImportJobRequest
impl Hash for CancelImportJobRequest
Sourceimpl Message for CancelImportJobRequest
impl Message for CancelImportJobRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for CancelImportJobRequest
impl PartialEq for CancelImportJobRequest
impl StructuralPartialEq for CancelImportJobRequest