pub struct ChangeThreadLifecycleRequest {
pub client_operation_id: String,
pub thread: Option<ThreadRef>,
pub expected_version: Vec<u8>,
pub lifecycle: i32,
pub operation: Option<SignedRecord>,
}Fields
client_operation_id: Stringthread: Option<ThreadRef>expected_version: Vec<u8>lifecycle: i32operation: Option<SignedRecord>READY revalidates requirements. LANDED is rejected here; use LandThread.
Implementations
Sourceimpl ChangeThreadLifecycleRequest
impl ChangeThreadLifecycleRequest
Sourcepub fn lifecycle(&self) -> ThreadLifecycle
pub fn lifecycle(&self) -> ThreadLifecycle
Returns the enum value of lifecycle, or the default if the field is set to an invalid enum value.
Sourcepub fn set_lifecycle(&mut self, value: ThreadLifecycle)
pub fn set_lifecycle(&mut self, value: ThreadLifecycle)
Sets lifecycle to the provided enum value.