pub struct CodeSemanticRef {
pub source: Option<CodeOccurrence>,
pub target: Option<CodeSymbol>,
pub kind: i32,
pub hop: u32,
}Expand description
Original source-to-target orientation, also for incoming/caller queries.
Fields
source: Option<CodeOccurrence>target: Option<CodeSymbol>kind: i32hop: u32One-based distance from the query root, at most hop_cap.
Implementations
Sourceimpl CodeSemanticRef
impl CodeSemanticRef
Sourcepub fn kind(&self) -> CodeEdgeKind
pub fn kind(&self) -> CodeEdgeKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: CodeEdgeKind)
pub fn set_kind(&mut self, value: CodeEdgeKind)
Sets kind to the provided enum value.