pub struct ContentTreeEntry {
pub path: String,
pub last_changed_at: Option<Timestamp>,
pub last_changed_by: Option<StatePrincipal>,
pub target: Option<Target>,
}Fields
path: StringRepository-root-relative path, including the requested subtree prefix.
last_changed_at: Option<Timestamp>Present only when the corresponding provenance has been published and authorized. Absence does not mean that the source has no history.
last_changed_by: Option<StatePrincipal>target: Option<Target>Trait Implementations
Sourceimpl Clone for ContentTreeEntry
impl Clone for ContentTreeEntry
Sourcefn clone(&self) -> ContentTreeEntry
fn clone(&self) -> ContentTreeEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ContentTreeEntry
impl Debug for ContentTreeEntry
Sourceimpl Default for ContentTreeEntry
impl Default for ContentTreeEntry
Sourcefn default() -> ContentTreeEntry
fn default() -> ContentTreeEntry
Returns the “default value” for a type. Read more
impl Eq for ContentTreeEntry
Sourceimpl Hash for ContentTreeEntry
impl Hash for ContentTreeEntry
Sourceimpl Message for ContentTreeEntry
impl Message for ContentTreeEntry
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ContentTreeEntry
impl PartialEq for ContentTreeEntry
impl StructuralPartialEq for ContentTreeEntry