pub struct CreateAnonymousSessionRequest {
pub client_operation_id: String,
pub continuity_secret: Vec<u8>,
pub abuse_challenge_proof: String,
}Expand description
Anonymous continuity has no human account and no independent owner root. The endpoint retains its existing anti-abuse, expiry and rotation checks.
Fields
client_operation_id: Stringcontinuity_secret: Vec<u8>abuse_challenge_proof: StringTrait Implementations
Sourceimpl Clone for CreateAnonymousSessionRequest
impl Clone for CreateAnonymousSessionRequest
Sourcefn clone(&self) -> CreateAnonymousSessionRequest
fn clone(&self) -> CreateAnonymousSessionRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for CreateAnonymousSessionRequest
impl Default for CreateAnonymousSessionRequest
Sourcefn default() -> CreateAnonymousSessionRequest
fn default() -> CreateAnonymousSessionRequest
Returns the “default value” for a type. Read more
impl Eq for CreateAnonymousSessionRequest
Sourceimpl Hash for CreateAnonymousSessionRequest
impl Hash for CreateAnonymousSessionRequest
Sourceimpl Message for CreateAnonymousSessionRequest
impl Message for CreateAnonymousSessionRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl StructuralPartialEq for CreateAnonymousSessionRequest