pub struct CustodialEmailBinding {
pub format_version: u32,
pub account_uuid: Vec<u8>,
pub attempt_uuid: Vec<u8>,
pub proposed_root_public_key: Vec<u8>,
pub challenge: Vec<u8>,
pub expires_at_unix_seconds: i64,
}Expand description
Fixed-width canonical v1: u32 version, raw16 account UUID, raw16 attempt UUID, raw32 proposed Ed25519 root, raw32 challenge, i64 expiry (big endian). Email possession authorizes only this attempt, never account/spool access.
Fields
format_version: u32Exactly 1.
account_uuid: Vec<u8>attempt_uuid: Vec<u8>proposed_root_public_key: Vec<u8>challenge: Vec<u8>expires_at_unix_seconds: i64Trait Implementations
Sourceimpl Clone for CustodialEmailBinding
impl Clone for CustodialEmailBinding
Sourcefn clone(&self) -> CustodialEmailBinding
fn clone(&self) -> CustodialEmailBinding
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CustodialEmailBinding
impl Debug for CustodialEmailBinding
Sourceimpl Default for CustodialEmailBinding
impl Default for CustodialEmailBinding
Sourcefn default() -> CustodialEmailBinding
fn default() -> CustodialEmailBinding
Returns the “default value” for a type. Read more
impl Eq for CustodialEmailBinding
Sourceimpl Hash for CustodialEmailBinding
impl Hash for CustodialEmailBinding
Sourceimpl Message for CustodialEmailBinding
impl Message for CustodialEmailBinding
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for CustodialEmailBinding
impl PartialEq for CustodialEmailBinding
impl StructuralPartialEq for CustodialEmailBinding