pub struct GetFileSymbolsRequest {
pub revision: Option<RevisionRef>,
pub thread: Option<ThreadRef>,
pub path: String,
pub page: Option<PageRequest>,
pub budget: Option<ReadBudget>,
}Fields
revision: Option<RevisionRef>thread: Option<ThreadRef>path: Stringpage: Option<PageRequest>budget: Option<ReadBudget>Trait Implementations
Sourceimpl Clone for GetFileSymbolsRequest
impl Clone for GetFileSymbolsRequest
Sourcefn clone(&self) -> GetFileSymbolsRequest
fn clone(&self) -> GetFileSymbolsRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetFileSymbolsRequest
impl Debug for GetFileSymbolsRequest
Sourceimpl Default for GetFileSymbolsRequest
impl Default for GetFileSymbolsRequest
Sourcefn default() -> GetFileSymbolsRequest
fn default() -> GetFileSymbolsRequest
Returns the “default value” for a type. Read more
impl Eq for GetFileSymbolsRequest
Sourceimpl Hash for GetFileSymbolsRequest
impl Hash for GetFileSymbolsRequest
Sourceimpl Message for GetFileSymbolsRequest
impl Message for GetFileSymbolsRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for GetFileSymbolsRequest
impl PartialEq for GetFileSymbolsRequest
impl StructuralPartialEq for GetFileSymbolsRequest