pub struct GetSemanticImportersResponse {
pub metadata: Option<CodeNavigationMetadata>,
pub importers: Vec<CodeImporter>,
pub page: Option<PageInfo>,
pub truncated: bool,
pub reason: i32,
}Fields
metadata: Option<CodeNavigationMetadata>importers: Vec<CodeImporter>page: Option<PageInfo>truncated: boolreason: i32Implementations
Sourceimpl GetSemanticImportersResponse
impl GetSemanticImportersResponse
Sourcepub fn reason(&self) -> CodeNavigationReason
pub fn reason(&self) -> CodeNavigationReason
Returns the enum value of reason, or the default if the field is set to an invalid enum value.
Sourcepub fn set_reason(&mut self, value: CodeNavigationReason)
pub fn set_reason(&mut self, value: CodeNavigationReason)
Sets reason to the provided enum value.