pub struct ImportAuthorityWitnessV1 {
pub format_version: u32,
pub kind: i32,
pub original: Option<SignedRecord>,
pub dependencies: Vec<SignedRecord>,
pub authority_envelope: Vec<u8>,
}Fields
format_version: u32kind: i32original: Option<SignedRecord>dependencies: Vec<SignedRecord>Sorted signed-native-record digests.
Implementations
Sourceimpl ImportAuthorityWitnessV1
impl ImportAuthorityWitnessV1
Sourcepub fn kind(&self) -> ImportAuthorityRecordKind
pub fn kind(&self) -> ImportAuthorityRecordKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: ImportAuthorityRecordKind)
pub fn set_kind(&mut self, value: ImportAuthorityRecordKind)
Sets kind to the provided enum value.