pub struct ImportGenesisAuthorityV1 {
pub format_version: u32,
pub identity: Option<ImportIdentityV1>,
pub genesis_digest: Vec<u8>,
pub original_creator_signature: Vec<u8>,
pub creator_public_key: Vec<u8>,
pub creator_authority_envelope_digest: Vec<u8>,
pub parent_permission_digest: Vec<u8>,
pub owner_chain_digest: Vec<u8>,
}Fields
format_version: u32identity: Option<ImportIdentityV1>genesis_digest: Vec<u8>original_creator_signature: Vec<u8>64 bytes, preserved unchanged.
creator_public_key: Vec<u8>parent_permission_digest: Vec<u8>Zero32 only for direct active owner authority.
owner_chain_digest: Vec<u8>Trait Implementations
Sourceimpl Canonical for ImportGenesisAuthorityV1
impl Canonical for ImportGenesisAuthorityV1
Sourceimpl Clone for ImportGenesisAuthorityV1
impl Clone for ImportGenesisAuthorityV1
Sourcefn clone(&self) -> ImportGenesisAuthorityV1
fn clone(&self) -> ImportGenesisAuthorityV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ImportGenesisAuthorityV1
impl Debug for ImportGenesisAuthorityV1
Sourceimpl Default for ImportGenesisAuthorityV1
impl Default for ImportGenesisAuthorityV1
Sourcefn default() -> ImportGenesisAuthorityV1
fn default() -> ImportGenesisAuthorityV1
Returns the “default value” for a type. Read more
impl Eq for ImportGenesisAuthorityV1
Sourceimpl Hash for ImportGenesisAuthorityV1
impl Hash for ImportGenesisAuthorityV1
Sourceimpl Message for ImportGenesisAuthorityV1
impl Message for ImportGenesisAuthorityV1
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ImportGenesisAuthorityV1
impl PartialEq for ImportGenesisAuthorityV1
impl StructuralPartialEq for ImportGenesisAuthorityV1