pub struct ImportGenesisWitnessV1 {
pub format_version: u32,
pub binding: Option<SignedImportGenesisAuthorityV1>,
pub original_genesis: Option<SignedRecord>,
pub creator_authority_envelope: Vec<u8>,
}Expand description
Typed purpose payloads use the same fixed-order canonical framing. SignedRecord flattens counted format, counted original native bytes, signature count then counted key/signature pairs, sorted by raw key. Native bytes are never changed.
Fields
format_version: u32binding: Option<SignedImportGenesisAuthorityV1>original_genesis: Option<SignedRecord>Trait Implementations
Sourceimpl Canonical for ImportGenesisWitnessV1
impl Canonical for ImportGenesisWitnessV1
Sourceimpl Clone for ImportGenesisWitnessV1
impl Clone for ImportGenesisWitnessV1
Sourcefn clone(&self) -> ImportGenesisWitnessV1
fn clone(&self) -> ImportGenesisWitnessV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ImportGenesisWitnessV1
impl Debug for ImportGenesisWitnessV1
Sourceimpl Default for ImportGenesisWitnessV1
impl Default for ImportGenesisWitnessV1
Sourcefn default() -> ImportGenesisWitnessV1
fn default() -> ImportGenesisWitnessV1
Returns the “default value” for a type. Read more
Sourceimpl Message for ImportGenesisWitnessV1
impl Message for ImportGenesisWitnessV1
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ImportGenesisWitnessV1
impl PartialEq for ImportGenesisWitnessV1
impl StructuralPartialEq for ImportGenesisWitnessV1