pub struct ImportJobCasStateV1 {
pub format_version: u32,
pub logical_job_id: Vec<u8>,
pub retry_lineage_id: Vec<u8>,
pub active_predecessor: Option<SignedImportJobDelegationV1>,
pub authority_epoch: u64,
pub committed_manifest: Option<ImportResultManifestV1>,
}Fields
format_version: u32logical_job_id: Vec<u8>retry_lineage_id: Vec<u8>active_predecessor: Option<SignedImportJobDelegationV1>committed_manifest: Option<ImportResultManifestV1>Trait Implementations
Sourceimpl Canonical for ImportJobCasStateV1
impl Canonical for ImportJobCasStateV1
Sourceimpl Clone for ImportJobCasStateV1
impl Clone for ImportJobCasStateV1
Sourcefn clone(&self) -> ImportJobCasStateV1
fn clone(&self) -> ImportJobCasStateV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ImportJobCasStateV1
impl Debug for ImportJobCasStateV1
Sourceimpl Default for ImportJobCasStateV1
impl Default for ImportJobCasStateV1
Sourcefn default() -> ImportJobCasStateV1
fn default() -> ImportJobCasStateV1
Returns the “default value” for a type. Read more
Sourceimpl Message for ImportJobCasStateV1
impl Message for ImportJobCasStateV1
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ImportJobCasStateV1
impl PartialEq for ImportJobCasStateV1
impl StructuralPartialEq for ImportJobCasStateV1