pub struct ImportJobRenewalV1 {
pub format_version: u32,
pub predecessor_delegation_digest: Vec<u8>,
pub expected_authority_epoch: u64,
pub committed_manifest_digest: Vec<u8>,
pub replacement: Option<SignedImportJobDelegationV1>,
}Expand description
P2 #2: replacement includes only uncommitted slots, preserves original geneses/envelopes/first receipts and uses a fresh key. expected_authority_epoch and committed_manifest_digest CAS serialize two renewals with publication.
Fields
format_version: u32predecessor_delegation_digest: Vec<u8>committed_manifest_digest: Vec<u8>replacement: Option<SignedImportJobDelegationV1>Trait Implementations
Sourceimpl Canonical for ImportJobRenewalV1
impl Canonical for ImportJobRenewalV1
Sourceimpl Clone for ImportJobRenewalV1
impl Clone for ImportJobRenewalV1
Sourcefn clone(&self) -> ImportJobRenewalV1
fn clone(&self) -> ImportJobRenewalV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ImportJobRenewalV1
impl Debug for ImportJobRenewalV1
Sourceimpl Default for ImportJobRenewalV1
impl Default for ImportJobRenewalV1
Sourcefn default() -> ImportJobRenewalV1
fn default() -> ImportJobRenewalV1
Returns the “default value” for a type. Read more
Sourceimpl Message for ImportJobRenewalV1
impl Message for ImportJobRenewalV1
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ImportJobRenewalV1
impl PartialEq for ImportJobRenewalV1
impl StructuralPartialEq for ImportJobRenewalV1