pub struct ImportPreparationRefusalV1 {
pub reason: i32,
pub field: String,
}Fields
reason: i32field: StringBounded request field path; never hidden resource details.
Implementations
Sourceimpl ImportPreparationRefusalV1
impl ImportPreparationRefusalV1
Sourcepub fn reason(&self) -> ImportPreparationRefusalReason
pub fn reason(&self) -> ImportPreparationRefusalReason
Returns the enum value of reason, or the default if the field is set to an invalid enum value.
Sourcepub fn set_reason(&mut self, value: ImportPreparationRefusalReason)
pub fn set_reason(&mut self, value: ImportPreparationRefusalReason)
Sets reason to the provided enum value.