pub struct ImportPublicProofBundleV1 {Show 22 fields
pub format_version: u32,
pub owner_genesis: Option<SignedSpoolOwnerGenesis>,
pub owner_histories: Vec<OwnerHistory>,
pub ownership_transfers: Vec<ResourceTransferAuditRecord>,
pub member_permission: Option<SignedImportMemberPermissionV1>,
pub genesis_authorities: Vec<SignedImportGenesisAuthorityV1>,
pub delegations: Vec<SignedImportJobDelegationV1>,
pub renewals: Vec<SignedImportJobRenewalV1>,
pub operations: Vec<SignedDelegatedImportOperationV1>,
pub terminal_manifest: Option<ImportResultManifestV1>,
pub witness_set: Option<SignedHostedWitnessSetV1>,
pub statements: Vec<SignedHostedWitnessStatementV1>,
pub history_proofs: Vec<HostedWitnessHistoryProofV1>,
pub policies: Vec<SignedSpoolPolicyRecord>,
pub original_geneses: Vec<SignedRecord>,
pub creator_authority_envelopes: Vec<Vec<u8>>,
pub owner_chain: Option<ImportOwnerChainV1>,
pub member_permissions: Vec<SignedImportMemberPermissionV1>,
pub manifests: Vec<ImportResultManifestV1>,
pub genesis_witnesses: Vec<ImportGenesisWitnessV1>,
pub authority_witnesses: Vec<ImportAuthorityWitnessV1>,
pub landing_witnesses: Vec<HostedLandingWitnessV1>,
}Expand description
Owner verification belongs to heddle capability-verifier: independently select the immutable lineage, verify owner histories/handoffs and current or witnessed historical authority. This public carrier cannot enroll its owner.
Fields
format_version: u32owner_genesis: Option<SignedSpoolOwnerGenesis>owner_histories: Vec<OwnerHistory>ownership_transfers: Vec<ResourceTransferAuditRecord>member_permission: Option<SignedImportMemberPermissionV1>Absent for direct owner.
delegations: Vec<SignedImportJobDelegationV1>Initial plus accepted renewals.
renewals: Vec<SignedImportJobRenewalV1>operations: Vec<SignedDelegatedImportOperationV1>terminal_manifest: Option<ImportResultManifestV1>witness_set: Option<SignedHostedWitnessSetV1>statements: Vec<SignedHostedWitnessStatementV1>history_proofs: Vec<HostedWitnessHistoryProofV1>policies: Vec<SignedSpoolPolicyRecord>original_geneses: Vec<SignedRecord>owner_chain: Option<ImportOwnerChainV1>member_permissions: Vec<SignedImportMemberPermissionV1>Authoritative digest-sorted unique history. Field 5 is an optional alias; field 10 is the required terminal selector. Both MUST equal exact entries. Never rewrite old signed records.
At most 64.
manifests: Vec<ImportResultManifestV1>At most 320.
genesis_witnesses: Vec<ImportGenesisWitnessV1>Exact statement payloads, indexed by H(purpose-domain || canonical payload).
landing_witnesses: Vec<HostedLandingWitnessV1>Trait Implementations
Sourceimpl Clone for ImportPublicProofBundleV1
impl Clone for ImportPublicProofBundleV1
Sourcefn clone(&self) -> ImportPublicProofBundleV1
fn clone(&self) -> ImportPublicProofBundleV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ImportPublicProofBundleV1
impl Debug for ImportPublicProofBundleV1
Sourceimpl Default for ImportPublicProofBundleV1
impl Default for ImportPublicProofBundleV1
Sourcefn default() -> ImportPublicProofBundleV1
fn default() -> ImportPublicProofBundleV1
Returns the “default value” for a type. Read more
Sourceimpl Message for ImportPublicProofBundleV1
impl Message for ImportPublicProofBundleV1
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl StructuralPartialEq for ImportPublicProofBundleV1