pub struct ImportSourceSelectionV1 {
pub connection: Option<RecordRef>,
pub provider_repository_id: String,
pub installation_id: String,
pub private: bool,
}Expand description
Explicit custody selector. The URL is proposed_scope.source_url. The host resolves this selector for the authenticated caller at Prepare and Commit; a domain alone NEVER selects credential custody. Identifiers/visibility only: no credentials, grants or execution authority.
Fields
connection: Option<RecordRef>Absent for unconnected public HTTPS Git.
provider_repository_id: Stringinstallation_id: Stringprivate: boolTrait Implementations
Sourceimpl Clone for ImportSourceSelectionV1
impl Clone for ImportSourceSelectionV1
Sourcefn clone(&self) -> ImportSourceSelectionV1
fn clone(&self) -> ImportSourceSelectionV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ImportSourceSelectionV1
impl Debug for ImportSourceSelectionV1
Sourceimpl Default for ImportSourceSelectionV1
impl Default for ImportSourceSelectionV1
Sourcefn default() -> ImportSourceSelectionV1
fn default() -> ImportSourceSelectionV1
Returns the “default value” for a type. Read more
impl Eq for ImportSourceSelectionV1
Sourceimpl Hash for ImportSourceSelectionV1
impl Hash for ImportSourceSelectionV1
Sourceimpl Message for ImportSourceSelectionV1
impl Message for ImportSourceSelectionV1
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ImportSourceSelectionV1
impl PartialEq for ImportSourceSelectionV1
impl StructuralPartialEq for ImportSourceSelectionV1