pub struct NotificationDigestOverride {
pub spool: Option<SpoolRef>,
pub digest_interval: Option<Duration>,
}Fields
spool: Option<SpoolRef>digest_interval: Option<Duration>Required, with the same values as the account default. Explicit zero means off for this Spool, even when the account default enables digests.