pub struct NotificationRecord {
pub ref: Option<RecordRef>,
pub version: Vec<u8>,
pub subject: Option<EntityRef>,
pub kind: String,
pub title: String,
pub body: String,
pub created_at: Option<Timestamp>,
pub read_at: Option<Timestamp>,
pub actions: Vec<ActionAvailability>,
}Fields
ref: Option<RecordRef>version: Vec<u8>subject: Option<EntityRef>kind: Stringtitle: Stringbody: Stringcreated_at: Option<Timestamp>read_at: Option<Timestamp>actions: Vec<ActionAvailability>Trait Implementations
Sourceimpl Clone for NotificationRecord
impl Clone for NotificationRecord
Sourcefn clone(&self) -> NotificationRecord
fn clone(&self) -> NotificationRecord
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NotificationRecord
impl Debug for NotificationRecord
Sourceimpl Default for NotificationRecord
impl Default for NotificationRecord
Sourcefn default() -> NotificationRecord
fn default() -> NotificationRecord
Returns the “default value” for a type. Read more
Sourceimpl Message for NotificationRecord
impl Message for NotificationRecord
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for NotificationRecord
impl PartialEq for NotificationRecord
impl StructuralPartialEq for NotificationRecord