pub struct PairingInitiationBinding {
pub host: Option<EndpointRef>,
pub client_operation_id: String,
pub subject_public_key: Vec<u8>,
pub not_before_unix_seconds: i64,
pub expires_at_unix_seconds: i64,
pub receiver: Option<Receiver>,
}Fields
host: Option<EndpointRef>client_operation_id: Stringsubject_public_key: Vec<u8>not_before_unix_seconds: i64expires_at_unix_seconds: i64receiver: Option<Receiver>Trait Implementations
Sourceimpl Clone for PairingInitiationBinding
impl Clone for PairingInitiationBinding
Sourcefn clone(&self) -> PairingInitiationBinding
fn clone(&self) -> PairingInitiationBinding
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PairingInitiationBinding
impl Debug for PairingInitiationBinding
Sourceimpl Default for PairingInitiationBinding
impl Default for PairingInitiationBinding
Sourcefn default() -> PairingInitiationBinding
fn default() -> PairingInitiationBinding
Returns the “default value” for a type. Read more
impl Eq for PairingInitiationBinding
Sourceimpl Hash for PairingInitiationBinding
impl Hash for PairingInitiationBinding
Sourceimpl Message for PairingInitiationBinding
impl Message for PairingInitiationBinding
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for PairingInitiationBinding
impl PartialEq for PairingInitiationBinding
impl StructuralPartialEq for PairingInitiationBinding