pub struct PasskeyMintGrant {
pub format_version: u32,
pub mint_root_key: Option<AuthorizationVerificationKey>,
pub not_before_unix_seconds: i64,
pub expires_at_unix_seconds: i64,
pub nonce: Vec<u8>,
pub relying_party_id: String,
}Expand description
Account-free request for one passkey to authorize a temporary Ed25519 mint key. Canonical v1 fields follow tag order using fixed-width/length-prefixed encoding. Domain: “heddle-passkey-mint-grant-v1”. The WebAuthn challenge is SHA-256(domain || canonical fields). Account and owner fields are deliberately absent and MUST be derived from PasskeyMintDelegation.authority.
Fields
format_version: u32mint_root_key: Option<AuthorizationVerificationKey>not_before_unix_seconds: i64expires_at_unix_seconds: i64nonce: Vec<u8>relying_party_id: StringTrait Implementations
Sourceimpl Clone for PasskeyMintGrant
impl Clone for PasskeyMintGrant
Sourcefn clone(&self) -> PasskeyMintGrant
fn clone(&self) -> PasskeyMintGrant
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PasskeyMintGrant
impl Debug for PasskeyMintGrant
Sourceimpl Default for PasskeyMintGrant
impl Default for PasskeyMintGrant
Sourcefn default() -> PasskeyMintGrant
fn default() -> PasskeyMintGrant
Returns the “default value” for a type. Read more
impl Eq for PasskeyMintGrant
Sourceimpl Hash for PasskeyMintGrant
impl Hash for PasskeyMintGrant
Sourceimpl Message for PasskeyMintGrant
impl Message for PasskeyMintGrant
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for PasskeyMintGrant
impl PartialEq for PasskeyMintGrant
impl StructuralPartialEq for PasskeyMintGrant