pub struct PurgeOperationSigningBody {
pub format_version: u32,
pub spool_uuid: Vec<u8>,
pub purge_identity: Option<PurgeSidecarIdentity>,
pub payload_sha256: Vec<u8>,
pub leaf_capability_id: Vec<u8>,
}Expand description
Protobuf serialization is never signed. canonical_purge_operation_v2 is: u32_be(format_version), raw 16-byte spool_uuid, blob_hash as a u32-length- prefixed string, raw 32-byte payload_sha256, raw 32-byte leaf_capability_id. The leaf subject signs SHA-256(“heddle-purge-operation-v2” || canonical_body). The verifier binds this body to the actual spool, payload and direct PURGE grant. Moving the RPC package does not change this durable signing format.
Fields
format_version: u32Exactly 2.
spool_uuid: Vec<u8>purge_identity: Option<PurgeSidecarIdentity>payload_sha256: Vec<u8>leaf_capability_id: Vec<u8>Trait Implementations
Sourceimpl Clone for PurgeOperationSigningBody
impl Clone for PurgeOperationSigningBody
Sourcefn clone(&self) -> PurgeOperationSigningBody
fn clone(&self) -> PurgeOperationSigningBody
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PurgeOperationSigningBody
impl Debug for PurgeOperationSigningBody
Sourceimpl Default for PurgeOperationSigningBody
impl Default for PurgeOperationSigningBody
Sourcefn default() -> PurgeOperationSigningBody
fn default() -> PurgeOperationSigningBody
Returns the “default value” for a type. Read more
impl Eq for PurgeOperationSigningBody
Sourceimpl Hash for PurgeOperationSigningBody
impl Hash for PurgeOperationSigningBody
Sourceimpl Message for PurgeOperationSigningBody
impl Message for PurgeOperationSigningBody
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl StructuralPartialEq for PurgeOperationSigningBody