pub struct RecoveryArgon2idParams {
pub memory_kib: u32,
pub iterations: u32,
pub parallelism: u32,
}Fields
memory_kib: u32iterations: u32parallelism: u32Trait Implementations
Sourceimpl Clone for RecoveryArgon2idParams
impl Clone for RecoveryArgon2idParams
Sourcefn clone(&self) -> RecoveryArgon2idParams
fn clone(&self) -> RecoveryArgon2idParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for RecoveryArgon2idParams
Sourceimpl Debug for RecoveryArgon2idParams
impl Debug for RecoveryArgon2idParams
Sourceimpl Default for RecoveryArgon2idParams
impl Default for RecoveryArgon2idParams
Sourcefn default() -> RecoveryArgon2idParams
fn default() -> RecoveryArgon2idParams
Returns the “default value” for a type. Read more
impl Eq for RecoveryArgon2idParams
Sourceimpl Hash for RecoveryArgon2idParams
impl Hash for RecoveryArgon2idParams
Sourceimpl Message for RecoveryArgon2idParams
impl Message for RecoveryArgon2idParams
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for RecoveryArgon2idParams
impl PartialEq for RecoveryArgon2idParams
impl StructuralPartialEq for RecoveryArgon2idParams