pub struct SatisfiedPolicyRequirement {
pub kind: i32,
pub check: String,
pub group: Option<RecordRef>,
pub approvals: Vec<RecordRef>,
pub evidence: Vec<RecordRef>,
pub rule_source: i32,
pub review_policy: Option<RecordRef>,
pub rule_index: u32,
}Fields
kind: i32check: StringFor REQUIRED_CHECK, the exact policy check name.
group: Option<RecordRef>For REVIEW_GROUP, the exact policy group record.
approvals: Vec<RecordRef>Signed ReviewRecord.decision.ref values that passed the evaluator for the assessment’s source, target and policy. No opinions or previews here.
evidence: Vec<RecordRef>Signed EvidenceRecord.ref values that passed for the assessment’s source.
rule_source: i32review_policy: Option<RecordRef>rule_index: u32Implementations
Sourceimpl SatisfiedPolicyRequirement
impl SatisfiedPolicyRequirement
Sourcepub fn kind(&self) -> Kind
pub fn kind(&self) -> Kind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn rule_source(&self) -> RuleSource
pub fn rule_source(&self) -> RuleSource
Returns the enum value of rule_source, or the default if the field is set to an invalid enum value.
Sourcepub fn set_rule_source(&mut self, value: RuleSource)
pub fn set_rule_source(&mut self, value: RuleSource)
Sets rule_source to the provided enum value.