pub struct SetAttentionStateRequest {
pub client_operation_id: String,
pub item: Option<RecordRef>,
pub expected_version: Vec<u8>,
pub resolution: i32,
pub pinned: bool,
}Fields
client_operation_id: Stringitem: Option<RecordRef>expected_version: Vec<u8>resolution: i32pinned: boolImplementations
Sourceimpl SetAttentionStateRequest
impl SetAttentionStateRequest
Sourcepub fn resolution(&self) -> Resolution
pub fn resolution(&self) -> Resolution
Returns the enum value of resolution, or the default if the field is set to an invalid enum value.
Sourcepub fn set_resolution(&mut self, value: Resolution)
pub fn set_resolution(&mut self, value: Resolution)
Sets resolution to the provided enum value.