pub struct SetPrimaryHandleResponse {
pub receipt: Option<MutationReceipt>,
pub principal: Option<PrincipalRecord>,
pub public_handle: Option<PublicHandleRecord>,
}Fields
receipt: Option<MutationReceipt>principal: Option<PrincipalRecord>handle now names the primary handle; display_name keeps any explicit name.
public_handle: Option<PublicHandleRecord>Trait Implementations
Sourceimpl Clone for SetPrimaryHandleResponse
impl Clone for SetPrimaryHandleResponse
Sourcefn clone(&self) -> SetPrimaryHandleResponse
fn clone(&self) -> SetPrimaryHandleResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SetPrimaryHandleResponse
impl Debug for SetPrimaryHandleResponse
Sourceimpl Default for SetPrimaryHandleResponse
impl Default for SetPrimaryHandleResponse
Sourcefn default() -> SetPrimaryHandleResponse
fn default() -> SetPrimaryHandleResponse
Returns the “default value” for a type. Read more
Sourceimpl Message for SetPrimaryHandleResponse
impl Message for SetPrimaryHandleResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for SetPrimaryHandleResponse
impl PartialEq for SetPrimaryHandleResponse
impl StructuralPartialEq for SetPrimaryHandleResponse