pub struct SetSupportAccessRequest {
pub client_operation_id: String,
pub access: Option<SupportAccessRecord>,
pub expected_version: Vec<u8>,
}Fields
client_operation_id: Stringaccess: Option<SupportAccessRecord>expected_version: Vec<u8>Trait Implementations
Sourceimpl Clone for SetSupportAccessRequest
impl Clone for SetSupportAccessRequest
Sourcefn clone(&self) -> SetSupportAccessRequest
fn clone(&self) -> SetSupportAccessRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SetSupportAccessRequest
impl Debug for SetSupportAccessRequest
Sourceimpl Default for SetSupportAccessRequest
impl Default for SetSupportAccessRequest
Sourcefn default() -> SetSupportAccessRequest
fn default() -> SetSupportAccessRequest
Returns the “default value” for a type. Read more
impl Eq for SetSupportAccessRequest
Sourceimpl Hash for SetSupportAccessRequest
impl Hash for SetSupportAccessRequest
Sourceimpl Message for SetSupportAccessRequest
impl Message for SetSupportAccessRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for SetSupportAccessRequest
impl PartialEq for SetSupportAccessRequest
impl StructuralPartialEq for SetSupportAccessRequest