pub struct SetThreadAudienceRequest {
pub client_operation_id: String,
pub policy: Option<ThreadAudiencePolicy>,
pub expected_policy_version: Vec<u8>,
pub operation: Option<SignedRecord>,
}Fields
client_operation_id: Stringpolicy: Option<ThreadAudiencePolicy>expected_policy_version: Vec<u8>operation: Option<SignedRecord>Trait Implementations
Sourceimpl Clone for SetThreadAudienceRequest
impl Clone for SetThreadAudienceRequest
Sourcefn clone(&self) -> SetThreadAudienceRequest
fn clone(&self) -> SetThreadAudienceRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SetThreadAudienceRequest
impl Debug for SetThreadAudienceRequest
Sourceimpl Default for SetThreadAudienceRequest
impl Default for SetThreadAudienceRequest
Sourcefn default() -> SetThreadAudienceRequest
fn default() -> SetThreadAudienceRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for SetThreadAudienceRequest
impl Message for SetThreadAudienceRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for SetThreadAudienceRequest
impl PartialEq for SetThreadAudienceRequest
impl StructuralPartialEq for SetThreadAudienceRequest