pub struct SignupInvitation {
pub ref: Option<RecordRef>,
pub version: Vec<u8>,
pub bound_email: String,
pub expires_at: Option<Timestamp>,
pub redeemed: bool,
pub revoked: bool,
pub distribution_id: String,
}Fields
ref: Option<RecordRef>version: Vec<u8>bound_email: Stringexpires_at: Option<Timestamp>redeemed: boolrevoked: booldistribution_id: StringTrait Implementations
Sourceimpl Clone for SignupInvitation
impl Clone for SignupInvitation
Sourcefn clone(&self) -> SignupInvitation
fn clone(&self) -> SignupInvitation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SignupInvitation
impl Debug for SignupInvitation
Sourceimpl Default for SignupInvitation
impl Default for SignupInvitation
Sourcefn default() -> SignupInvitation
fn default() -> SignupInvitation
Returns the “default value” for a type. Read more
impl Eq for SignupInvitation
Sourceimpl Hash for SignupInvitation
impl Hash for SignupInvitation
Sourceimpl Message for SignupInvitation
impl Message for SignupInvitation
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for SignupInvitation
impl PartialEq for SignupInvitation
impl StructuralPartialEq for SignupInvitation