pub struct SourceTargetResolutionEvent {
pub change: Option<Change>,
}Expand description
Shared map updates for anchors and tags. Snapshot/Upsert frames carry upsert; Remove frames carry remove. Deduplicate by key within a checkpoint batch. Maps clear with Thread collaboration / Spool context section replacement and replacement snapshots. Remove the entry when its last referrer leaves the observed window. Neither missing targets nor these events grant source access.
Fields
change: Option<Change>Trait Implementations
Sourceimpl Clone for SourceTargetResolutionEvent
impl Clone for SourceTargetResolutionEvent
Sourcefn clone(&self) -> SourceTargetResolutionEvent
fn clone(&self) -> SourceTargetResolutionEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SourceTargetResolutionEvent
impl Debug for SourceTargetResolutionEvent
Sourceimpl Default for SourceTargetResolutionEvent
impl Default for SourceTargetResolutionEvent
Sourcefn default() -> SourceTargetResolutionEvent
fn default() -> SourceTargetResolutionEvent
Returns the “default value” for a type. Read more
impl Eq for SourceTargetResolutionEvent
Sourceimpl Hash for SourceTargetResolutionEvent
impl Hash for SourceTargetResolutionEvent
Sourceimpl Message for SourceTargetResolutionEvent
impl Message for SourceTargetResolutionEvent
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl StructuralPartialEq for SourceTargetResolutionEvent