pub struct StreamData {
pub kind: i32,
}Fields
kind: i32Implementations
Sourceimpl StreamData
impl StreamData
Sourcepub fn kind(&self) -> StreamDataKind
pub fn kind(&self) -> StreamDataKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: StreamDataKind)
pub fn set_kind(&mut self, value: StreamDataKind)
Sets kind to the provided enum value.