pub struct ThreadAlternative {
pub head: Option<RevisionRef>,
pub producer: Option<CaptureSummary>,
pub diff: Option<ReviewComparison>,
pub reviews: Vec<ReviewRecord>,
pub assessment: Option<LandingAssessment>,
pub checks: Vec<CheckEvidenceCurrency>,
}Fields
head: Option<RevisionRef>producer: Option<CaptureSummary>Attribution comes from this head’s State; a missing producer stays unknown.
diff: Option<ReviewComparison>The exact comparison used when requesting diff frames for this head.
reviews: Vec<ReviewRecord>Only reviews bound to this head, selected target and policy version.
assessment: Option<LandingAssessment>checks: Vec<CheckEvidenceCurrency>Trait Implementations
Sourceimpl Clone for ThreadAlternative
impl Clone for ThreadAlternative
Sourcefn clone(&self) -> ThreadAlternative
fn clone(&self) -> ThreadAlternative
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ThreadAlternative
impl Debug for ThreadAlternative
Sourceimpl Default for ThreadAlternative
impl Default for ThreadAlternative
Sourcefn default() -> ThreadAlternative
fn default() -> ThreadAlternative
Returns the “default value” for a type. Read more
Sourceimpl Message for ThreadAlternative
impl Message for ThreadAlternative
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ThreadAlternative
impl PartialEq for ThreadAlternative
impl StructuralPartialEq for ThreadAlternative