pub struct ThreadQuery {
pub spools: Vec<SpoolRef>,
pub lifecycle: Vec<i32>,
pub readiness: Vec<i32>,
pub attention_for_principal: String,
pub participating_principal: String,
pub parent: Option<ThreadRef>,
pub text: String,
pub order: i32,
}Fields
spools: Vec<SpoolRef>lifecycle: Vec<i32>readiness: Vec<i32>attention_for_principal: Stringparticipating_principal: Stringparent: Option<ThreadRef>text: Stringorder: i32Endpoint-local results only. Browser composition reports source coverage.
Implementations
Sourceimpl ThreadQuery
impl ThreadQuery
Sourcepub fn lifecycle(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<ThreadLifecycle>> ⓘ
pub fn lifecycle( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<ThreadLifecycle>> ⓘ
Returns an iterator which yields the valid enum values contained in lifecycle.
Sourcepub fn push_lifecycle(&mut self, value: ThreadLifecycle)
pub fn push_lifecycle(&mut self, value: ThreadLifecycle)
Appends the provided enum value to lifecycle.
Sourcepub fn readiness(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<ReviewReadiness>> ⓘ
pub fn readiness( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<ReviewReadiness>> ⓘ
Returns an iterator which yields the valid enum values contained in readiness.
Sourcepub fn push_readiness(&mut self, value: ReviewReadiness)
pub fn push_readiness(&mut self, value: ReviewReadiness)
Appends the provided enum value to readiness.