pub struct UploadTimelineEvent {
pub position: u64,
pub kind: i32,
pub recorded_at: Option<Timestamp>,
pub tool_name: Option<i32>,
}Expand description
Dedicated event input; canonical encoded event size is at most 2048 bytes.
Fields
position: u640..2^63-1; batch positions are consecutive.
kind: i32Maps to the eight lowercase snake-case TimelineRecord.kind strings.
Unspecified/unknown is invalid.
recorded_at: Option<Timestamp>Valid microsecond-normalized device time, at most five minutes in the future at admission. Past timestamps are valid for offline drain.
tool_name: Option<i32>Present exactly for TOOL_STARTED or TOOL_FINISHED. Maps to Bash, Edit, Read, Write, Grep, Glob, Task or Other (at most 5 ASCII bytes).
Zero/unknown is invalid.
Implementations
Sourceimpl UploadTimelineEvent
impl UploadTimelineEvent
Sourcepub fn kind(&self) -> UploadTimelineEventKind
pub fn kind(&self) -> UploadTimelineEventKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: UploadTimelineEventKind)
pub fn set_kind(&mut self, value: UploadTimelineEventKind)
Sets kind to the provided enum value.
Sourcepub fn tool_name(&self) -> UploadTimelineTool
pub fn tool_name(&self) -> UploadTimelineTool
Returns the enum value of tool_name, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_tool_name(&mut self, value: UploadTimelineTool)
pub fn set_tool_name(&mut self, value: UploadTimelineTool)
Sets tool_name to the provided enum value.