pub struct WeftCustodyWarningConsent {
pub warning_version: u32,
pub warning_sha256: Vec<u8>,
pub acknowledged_at_unix_seconds: i64,
}Expand description
Versioned evidence that the user saw and accepted the exact 1-of-1 Weft custody warning. warning_sha256 is SHA-256 of the reviewed UTF-8 warning text for warning_version; unknown versions and digests fail closed.
Fields
warning_version: u32warning_sha256: Vec<u8>acknowledged_at_unix_seconds: i64Trait Implementations
Sourceimpl Clone for WeftCustodyWarningConsent
impl Clone for WeftCustodyWarningConsent
Sourcefn clone(&self) -> WeftCustodyWarningConsent
fn clone(&self) -> WeftCustodyWarningConsent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WeftCustodyWarningConsent
impl Debug for WeftCustodyWarningConsent
Sourceimpl Default for WeftCustodyWarningConsent
impl Default for WeftCustodyWarningConsent
Sourcefn default() -> WeftCustodyWarningConsent
fn default() -> WeftCustodyWarningConsent
Returns the “default value” for a type. Read more
impl Eq for WeftCustodyWarningConsent
Sourceimpl Hash for WeftCustodyWarningConsent
impl Hash for WeftCustodyWarningConsent
Sourceimpl Message for WeftCustodyWarningConsent
impl Message for WeftCustodyWarningConsent
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl StructuralPartialEq for WeftCustodyWarningConsent