pub struct Download<R: MessageReader<Error = Error>> { /* private fields */ }Implementations
Sourceimpl<R: MessageReader<Error = Error>> Download<R>
impl<R: MessageReader<Error = Error>> Download<R>
Sourcepub async fn stage(self, scratch: &Path) -> Result<StagedSource, Error>
pub async fn stage(self, scratch: &Path) -> Result<StagedSource, Error>
Consume one complete source download into bounded temporary files and validate its original causal ancestry and exact selected source closure.
Sourcepub async fn stage_with_import_carriers(
self,
scratch: &Path,
carriers: VerifiedImportCarriers,
) -> Result<StagedSource, Error>
pub async fn stage_with_import_carriers( self, scratch: &Path, carriers: VerifiedImportCarriers, ) -> Result<StagedSource, Error>
Use independently authenticated import certificates for original Git ancestry. Exact native binding is checked after the originals arrive.