pub trait ProviderConsentSigner {
// Required methods
fn verified_subject(&self) -> Result<String, Error>;
fn client_endpoint(&self) -> Result<EndpointRef, Error>;
fn public_key(&self) -> &[u8] ⓘ;
fn sign(&self, canonical: &[u8]) -> Result<Vec<u8>, Error>;
}Expand description
Implemented by the same credential that signed the Fetch opening. The server verifies this identity against its authenticated Biscuit subject and requires the signature key to equal the credential’s terminal cnf key.
Required Methods
fn verified_subject(&self) -> Result<String, Error>
fn client_endpoint(&self) -> Result<EndpointRef, Error>
fn public_key(&self) -> &[u8] ⓘ
fn sign(&self, canonical: &[u8]) -> Result<Vec<u8>, Error>
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".