is_reopen_retryable

Function is_reopen_retryable 

pub fn is_reopen_retryable(failure: &CallFailure) -> bool
Weft fail-fasts a stale exact selection with these retryable signals. A bare resend of the same selection would observe the same Aborted.