pub fn sync_protocol() -> Option<ProtocolCompatibility>Expand description
All ordinary Sync constructors use the same coordinated cutover switch.
pub fn sync_protocol() -> Option<ProtocolCompatibility>All ordinary Sync constructors use the same coordinated cutover switch.