pub struct PublicationAcceptancePlan { /* private fields */ }Expand description
Full immutable publication selection shared by the client and host. Retained receipts are verified separately and cannot silently become fresh proposals.
Implementations
Sourceimpl PublicationAcceptancePlan
impl PublicationAcceptancePlan
pub fn intent(&self) -> &PublicationIntent
pub fn manifest(&self) -> &OriginalPublicationManifest
pub fn proposed(&self) -> &BTreeMap<ContentHash, ProposedAcceptance>
pub fn acceptance_for( &self, subject: &ManifestSubject, ) -> Option<&ProposedAcceptance>