pub struct VerifiedAttachment { /* private fields */ }Expand description
Evidence verified at the caller’s supplied time. Keep the original credential private when retaining this binding, and reverify it when using the evidence again. This value is not a reusable authorization permit.
Implementations
Sourceimpl VerifiedAttachment
impl VerifiedAttachment
pub fn credential_revocation_ids(&self) -> &[String]
pub fn root_public_key(&self) -> &[u8] ⓘ
pub fn subject_public_key(&self) -> &[u8] ⓘ
pub fn expires_at_unix_seconds(&self) -> i64