Module complete_registration_request
heddle_
thread_
api
0.25.4
Module complete_
registration_
request
Module Items
Enums
In heddle_
thread_
api::
contract
heddle_thread_api
::
contract
Module
complete_
registration_
request
Nested message and enum types in
CompleteRegistrationRequest
.
Enums

Owner
New signup establishes an owner root. Claim preserves the original deferred root and appends CLAIM_DEFERRED_HUMAN. Adding a passkey/device does not implicitly replace an existing owner root or change rooting tier.
Proof