pub struct CodeOccurrence {
pub path: String,
pub local_id: u32,
pub name: String,
pub role: i32,
pub span: Option<CodeSpan>,
pub enclosing_symbol: Option<CodeSymbolAddress>,
}Fields
path: Stringlocal_id: u32name: Stringrole: i32span: Option<CodeSpan>enclosing_symbol: Option<CodeSymbolAddress>Present only if a unique enclosing definition is recorded and visible.
Implementations
Sourceimpl CodeOccurrence
impl CodeOccurrence
Sourcepub fn role(&self) -> CodeOccurrenceRole
pub fn role(&self) -> CodeOccurrenceRole
Returns the enum value of role, or the default if the field is set to an invalid enum value.
Sourcepub fn set_role(&mut self, value: CodeOccurrenceRole)
pub fn set_role(&mut self, value: CodeOccurrenceRole)
Sets role to the provided enum value.