pub struct CodeSymbol {
pub address: Option<CodeSymbolAddress>,
pub name: String,
pub kind: i32,
pub span: Option<CodeSpan>,
pub semantic_hash: Vec<u8>,
}Fields
address: Option<CodeSymbolAddress>name: Stringkind: i32span: Option<CodeSpan>semantic_hash: Vec<u8>Native hd-sem-sym-v1 meaning fingerprint, exactly 32 bytes, not a CAS key.
Implementations
Sourceimpl CodeSymbol
impl CodeSymbol
Sourcepub fn kind(&self) -> CodeSymbolKind
pub fn kind(&self) -> CodeSymbolKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: CodeSymbolKind)
pub fn set_kind(&mut self, value: CodeSymbolKind)
Sets kind to the provided enum value.