pub struct ImportJobDelegationV1 {Show 17 fields
pub format_version: u32,
pub identity: Option<ImportIdentityV1>,
pub delegation_id: Vec<u8>,
pub logical_job_id: Vec<u8>,
pub retry_lineage_id: Vec<u8>,
pub job_public_key: Vec<u8>,
pub job_key_id: Vec<u8>,
pub delegating_public_key: Vec<u8>,
pub parent_permission_digest: Vec<u8>,
pub owner_chain_digest: Vec<u8>,
pub purpose: i32,
pub scope: Option<ImportPermissionScopeV1>,
pub branch_manifest: Vec<ImportBranchManifestV1>,
pub not_before_unix_seconds: i64,
pub expires_at_unix_seconds: i64,
pub cancellation_id: Vec<u8>,
pub predecessor_delegation_digest: Vec<u8>,
}Fields
format_version: u32identity: Option<ImportIdentityV1>delegation_id: Vec<u8>Unique random 16 bytes, renewed certificates get new IDs.
logical_job_id: Vec<u8>retry_lineage_id: Vec<u8>job_public_key: Vec<u8>job_key_id: Vec<u8>heddle-key-v1(ED25519 u32be, raw key).
delegating_public_key: Vec<u8>parent_permission_digest: Vec<u8>owner_chain_digest: Vec<u8>purpose: i32scope: Option<ImportPermissionScopeV1>branch_manifest: Vec<ImportBranchManifestV1>not_before_unix_seconds: i64expires_at_unix_seconds: i64cancellation_id: Vec<u8>predecessor_delegation_digest: Vec<u8>Zero32 initially.
Implementations
Sourceimpl ImportJobDelegationV1
impl ImportJobDelegationV1
Sourcepub fn purpose(&self) -> ImportDelegationPurpose
pub fn purpose(&self) -> ImportDelegationPurpose
Returns the enum value of purpose, or the default if the field is set to an invalid enum value.
Sourcepub fn set_purpose(&mut self, value: ImportDelegationPurpose)
pub fn set_purpose(&mut self, value: ImportDelegationPurpose)
Sets purpose to the provided enum value.