pub struct ImportOperationSubject {
pub source_url: String,
pub provider: String,
pub provider_repository_id: String,
}Fields
source_url: StringSource admitted for this attempt. Credential-free URL: never project userinfo, secret query parameters, or a source hidden from this caller.
provider: StringProviderConnection.provider + ProviderRepository.provider_repository_id. Both populated or both empty; source_url or this pair must be nonempty.
provider_repository_id: StringTrait Implementations
Sourceimpl Clone for ImportOperationSubject
impl Clone for ImportOperationSubject
Sourcefn clone(&self) -> ImportOperationSubject
fn clone(&self) -> ImportOperationSubject
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ImportOperationSubject
impl Debug for ImportOperationSubject
Sourceimpl Default for ImportOperationSubject
impl Default for ImportOperationSubject
Sourcefn default() -> ImportOperationSubject
fn default() -> ImportOperationSubject
Returns the “default value” for a type. Read more
impl Eq for ImportOperationSubject
Sourceimpl Hash for ImportOperationSubject
impl Hash for ImportOperationSubject
Sourceimpl Message for ImportOperationSubject
impl Message for ImportOperationSubject
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ImportOperationSubject
impl PartialEq for ImportOperationSubject
impl StructuralPartialEq for ImportOperationSubject