pub fn is_reopen_retryable(failure: &CallFailure) -> boolExpand description
Weft fail-fasts a stale exact selection with these retryable signals.
A bare resend of the same selection would observe the same Aborted.
pub fn is_reopen_retryable(failure: &CallFailure) -> boolWeft fail-fasts a stale exact selection with these retryable signals.
A bare resend of the same selection would observe the same Aborted.